@@ -24,11 +24,7 @@
 #include <falcon/vm.h>
 #include <falcon/stream.h>
 #include "core_module.h"
-#include "core_messages.h"
-
-/*#
-   
-*/
+#include <falcon/eng_messages.h>
 
 /*#
    @class CmdlineParser
@@ -39,7 +35,7 @@
    bit more specific than just "operate".
 
    Some embedding applications may provide the scripts with a command line too;
-   in example, a "scanner" script in a FPS game may be provided with the objects
+   for example, a "scanner" script in a FPS game may be provided with the objects
    to search for in a "command line", that may be actually the string that represents
    its configuration in the user interface.
 
@@ -54,21 +50,21 @@
    The command line parser knows the following option categories:
 
    - @b short @b options: options consisting of a single character, case sensitive,
-     following a single "-". In example, "-a", "-B", "-x". Short options may be
-     chained in sequences of characters as, in example "-aBx" which is
+     following a single "-". For example, "-a", "-B", "-x". Short options may be
+     chained in sequences of characters as, for example "-aBx" which is
      equivalent to "-a -B -x". Short options may have also the special
      "switch off" semantic; if they are followed by a "-" sign, the parser
-     interprets it as a will to turn off some feature; in example, the
+     interprets it as a will to turn off some feature; for example, the
      sequence "-B-" means that the "B" option should be turned off.
      The semantic can be expressed also in chained options as "-aB-x".
 
    - @b long @b options: they consists of two minus followed by a word of any
-     length, as in example "--parameter", "--config", "--elements".
+     length, as for example "--parameter", "--config", "--elements".
      Long options are usually (but not necessarily) meant to receive a parameter,
-     in example "--debug off".
+     for example "--debug off".
 
    - @b free @b options: they are strings not leaded by any "-" sign. Usually the semantic
-     of a command gives free options a special meaning; in example the "cp" unix command
+     of a command gives free options a special meaning; for example the "cp" unix command
      accept an arbitrary amount of free options, where the first N-1 options are
      the name of the files to copy, and the Nth option is the copy destination.
      A single "-" not followed by any letter is considered a free option
@@ -82,7 +78,7 @@
 
    Short and long options may be parametric. The word (or string) following parametric
    option is considered the parameter of that option, and is not subject to parsing.
-   In example, if "--terminator" is a parametric option, it is possible to write
+   For example, if "--terminator" is a parametric option, it is possible to write
    "./myprg.fal --terminator -opt". The parameter "-opt" will be passed as-is to the
    script as "terminator" option parameter. In case of short option chaining,
    if more than one chained option is parametric, the parameter following the chained
@@ -94,7 +90,7 @@
    in the CmdlineParser class. The parser will call the methods of the subclasses as
    it finds options in the argument vector; the callbacks will configure the application,
    report errors and mis-usage, terminate the program on fatal errors and communicate
-   with the parser through member functions. In example, it is not necessary to declare
+   with the parser through member functions. For example, it is not necessary to declare
    in advance which are the parametric options; it's done on a per-option basis by calling
    the expectParam() method and returning to the parser.
 
@@ -208,7 +204,7 @@ namespace core {
    Start the parsing process. If args parameter is not provided, the method gets
    the content of the @a args global vector defined in the Core module.
 
-   Returns true if the parsing was complete, and false on error (in example,
+   Returns true if the parsing was complete, and false on error (for example,
    if some element in the array wasn't a string).
 */
 FALCON_FUNC  CmdlineParser_parse( ::Falcon::VMachine *vm )
@@ -221,14 +217,12 @@ FALCON_FUNC  CmdlineParser_parse( ::Falcon::VMachine *vm )
       // get the parameters from the VM args object
       i_params = vm->findGlobalItem( "args" );
       if ( i_params == 0 || ! i_params->isArray() ) {
-         vm->raiseRTError( new CodeError( ErrorParam( e_undef_sym ).extra( "args" ).hard() ) );
-         return;
+         throw new CodeError( ErrorParam( e_undef_sym ).extra( "args" ).hard() );
       }
    }
    else if ( ! i_params->isArray() )
    {
-      vm->raiseRTError( new ParamError( ErrorParam( e_inv_params ).extra( "( A )" ) ) );
-      return;
+      throw new ParamError( ErrorParam( e_inv_params ).extra( "( A )" ) );
    }
 
    CoreArray *args = i_params->asArray();
@@ -259,13 +253,8 @@ FALCON_FUNC  CmdlineParser_parse( ::Falcon::VMachine *vm )
       Item &i_opt = args->at( i );
       if ( !i_opt.isString() )
       {
-         vm->raiseRTError(
-            new ParamError( ErrorParam( e_param_type ).
-                  extra( vm->moduleString( rtl_cmdp_0 ) )
-               )
-            );
-
-         return;
+         throw new ParamError( ErrorParam( e_param_type ).
+                  extra( vm->moduleString( rtl_cmdp_0 ) ) );
       }
 
       String &opt = *i_opt.asString();
@@ -275,13 +264,9 @@ FALCON_FUNC  CmdlineParser_parse( ::Falcon::VMachine *vm )
          self->getProperty( "onValue", i_method );
          if ( i_method.methodize( self ) )
          {
-            vm->pushParameter( &currentOption );
+            vm->pushParameter( new CoreString(currentOption) );
             vm->pushParameter( i_opt );
             vm->callItemAtomic( i_method, 2 );
-            if( vm->hadEvent() )
-               return;
-
-            vm->resetEvent();
             state = t_none;
          }
          else
@@ -299,10 +284,6 @@ FALCON_FUNC  CmdlineParser_parse( ::Falcon::VMachine *vm )
          {
             vm->pushParameter( i_opt );
             vm->callItemAtomic( i_method, 1 );
-            if( vm->hadEvent() )
-               return;
-            vm->resetEvent();
-
          }
          else
          {
@@ -329,12 +310,10 @@ FALCON_FUNC  CmdlineParser_parse( ::Falcon::VMachine *vm )
                else {
                   //Minimal optimization; reuse the same string and memory
                   subParam = opt.subString( 2 );
-                  vm->pushParameter( &subParam );
+                  vm->pushParameter( new CoreString( subParam ) );
                }
 
                vm->callItemAtomic( i_method, 1 );
-               if( vm->hadEvent() )
-                  return;
                self->getProperty( "_request", _request );
                // value requested?
                if ( _request.asInteger() == 1 ) {
@@ -363,10 +342,8 @@ FALCON_FUNC  CmdlineParser_parse( ::Falcon::VMachine *vm )
                   self->getProperty( "onSwitchOff", i_method );
                   if ( i_method.methodize( self ) )
                   {
-                     vm->pushParameter( &subParam );
+                     vm->pushParameter( new CoreString(subParam) );
                      vm->callItemAtomic( i_method, 1 );
-                     if( vm->hadEvent() )
-                        return;
                  }
                   else
                   {
@@ -380,10 +357,8 @@ FALCON_FUNC  CmdlineParser_parse( ::Falcon::VMachine *vm )
                   self->getProperty( "onOption", i_method );
                   if ( i_method.methodize( self ) )
                   {
-                     vm->pushParameter( &subParam );
+                     vm->pushParameter( new CoreString(subParam) );
                      vm->callItemAtomic( i_method, 1 );
-                     if( vm->hadEvent() )
-                        return;
                   }
                   else
                   {
@@ -419,7 +394,6 @@ FALCON_FUNC  CmdlineParser_parse( ::Falcon::VMachine *vm )
    }
 
    self->setProperty( "lastParsed", (int64) i );
-   vm->resetEvent();
    vm->retval( true );
 }
 
