@@ -16,9 +16,11 @@
 #include <falcon/setup.h>
 #include <falcon/coretable.h>
 #include <falcon/vm.h>
-#include "core_messages.h"
+#include <falcon/globals.h>
+#include <falcon/corefunc.h>
 
 namespace Falcon {
+namespace core {
 
 /*#
    @class Table
@@ -32,10 +34,9 @@ FALCON_FUNC Table_init( VMachine* vm )
    Item *i_heading = vm->param( 0 );
    if ( i_heading != 0 && ! i_heading->isArray() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR(rtl_no_tabhead) ) ) );
-      return;
+         .extra( Engine::getMessage(rtl_no_tabhead) ) );
    }
 
    CoreTable* table = new CoreTable();
@@ -43,20 +44,23 @@ FALCON_FUNC Table_init( VMachine* vm )
    {
       if (! table->setHeader( i_heading->asArray() ) )
       {
-         vm->raiseModError( new ParamError( ErrorParam( e_param_type, __LINE__ )
+         throw new ParamError( ErrorParam( e_param_type, __LINE__ )
             .origin( e_orig_runtime )
-            .extra( FAL_STR(rtl_invalid_tabhead) ) ) );
-         return;
+            .extra( Engine::getMessage(rtl_invalid_tabhead) ) );
       }
    }
 
    uint32 order = table->order();
 
    // create the first table
-   CoreArray *page = new CoreArray( vm, vm->paramCount() );
+   CoreArray *page = new CoreArray( vm->paramCount() );
+   //page->mark(vm->generation());
    table->insertPage( vm->self().asObject(), page );
    table->setCurrentPage(0);
+
    CoreObject *self = vm->self().asObject();
+   self->setUserData( table );
+
 
    // now we can safely add every other row that has been passed.
    for (int i = 1; i < vm->paramCount(); i ++ )
@@ -64,21 +68,17 @@ FALCON_FUNC Table_init( VMachine* vm )
       Item *vi = vm->param(i);
       if( ! vi->isArray() || vi->asArray()->length() != order )
       {
-         String tempString = FAL_STR(rtl_invalid_tabrow);
+         String tempString = Engine::getMessage(rtl_invalid_tabrow);
          tempString += ": [";
          tempString.writeNumber( (int64)( i-1 ) );
          tempString += "]";
-         vm->raiseModError( new ParamError( ErrorParam( e_param_type, __LINE__ )
+         throw new ParamError( ErrorParam( e_param_type, __LINE__ )
             .origin( e_orig_runtime )
-            .extra( tempString ) ) );
-         return;
+            .extra( tempString ) );
       }
       vi->asArray()->table( self );
-
       table->insertRow( vi->asArray() );
    }
-
-   self->setUserData( table );
 }
 
 
@@ -97,10 +97,9 @@ FALCON_FUNC Table_setHeader( VMachine* vm )
    Item *i_heading = vm->param( 0 );
    if ( i_heading != 0 && ! i_heading->isArray() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR(rtl_no_tabhead) ) ) );
-      return;
+         .extra( Engine::getMessage(rtl_no_tabhead) ) );
    }
 
    CoreObject* self = vm->self().asObject();
@@ -108,18 +107,16 @@ FALCON_FUNC Table_setHeader( VMachine* vm )
 
    if ( table->order() != CoreTable::noitem )
    {
-      vm->raiseModError( new CodeError( ErrorParam( e_inv_state, __LINE__ )
+      throw new CodeError( ErrorParam( e_table_aconf, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR(rtl_tabhead_given) ) ) );
-      return;
+         .extra( Engine::getMessage(rtl_tabhead_given) ) );
    }
 
    if (! table->setHeader( i_heading->asArray() ) )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_param_type, __LINE__ )
+      throw new ParamError( ErrorParam( e_param_type, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR(rtl_invalid_tabhead) ) ) );
-      return;
+         .extra( Engine::getMessage(rtl_invalid_tabhead) ) );
    }
 }
 
@@ -137,10 +134,9 @@ FALCON_FUNC Table_getHeader( VMachine* vm )
    Item *i_pos = vm->param( 0 );
    if ( i_pos != 0 && ! i_pos->isOrdinal() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "(N)" ) ) );
-      return;
+         .extra( "(N)" ) );
    }
 
    if( i_pos != 0 )
@@ -148,20 +144,19 @@ FALCON_FUNC Table_getHeader( VMachine* vm )
       uint32 pos = (uint32) i_pos->forceInteger();
       if( pos > table->order() )
       {
-         vm->raiseModError( new ParamError( ErrorParam( e_param_range, __LINE__ )
-         .origin( e_orig_runtime ) ) );
-         return;
+         throw new ParamError( ErrorParam( e_param_range, __LINE__ )
+         .origin( e_orig_runtime ) );
       }
 
-      vm->retval( new GarbageString( vm, table->heading(pos) ) );
+      vm->retval( new CoreString(  table->heading(pos) ) );
    }
    else {
-      CoreArray *ret = new CoreArray(vm, table->order() );
+      CoreArray *ret = new CoreArray( table->order() );
       ret->resize( table->order() );
 
       for( uint32 i = 0; i < table->order(); i ++ )
       {
-         ret->at(i) = new GarbageString( vm, table->heading( i ) );
+         ret->at(i) = new CoreString( table->heading( i ) );
       }
 
       vm->retval( ret );
@@ -184,10 +179,9 @@ FALCON_FUNC Table_getColData( VMachine* vm )
    Item *i_pos = vm->param( 0 );
    if ( i_pos != 0 && ! i_pos->isOrdinal() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "(N)" ) ) );
-      return;
+         .extra( "(N)" ) );
    }
 
    if( i_pos != 0 )
@@ -195,16 +189,14 @@ FALCON_FUNC Table_getColData( VMachine* vm )
       uint32 pos = (uint32) i_pos->forceInteger();
       if( pos > table->order() )
       {
-         vm->raiseModError( new ParamError( ErrorParam( e_param_range, __LINE__ )
-         .origin( e_orig_runtime ) ) );
-         return;
+         throw new ParamError( ErrorParam( e_param_range, __LINE__ )
+         .origin( e_orig_runtime ) );
       }
 
       vm->retval( table->columnData(pos) );
    }
    else {
-      CoreArray *ret = new CoreArray(vm, table->order() );
-
+      CoreArray *ret = new CoreArray( table->order() );
       for( uint32 i = 0; i < table->order(); i ++ )
       {
          ret->append( table->columnData(i) );
@@ -255,8 +247,7 @@ FALCON_FUNC Table_len( VMachine* vm )
    @raise AccessError if the table is empty.
    @return The first item in the table.
 
-   This method overloads the BOM method @a BOM.front. If the table
-   is not empty, it returns the first element.
+   If the table is not empty, it returns the first element (row) in the table.
 */
 FALCON_FUNC  Table_front ( ::Falcon::VMachine *vm )
 {
@@ -264,9 +255,8 @@ FALCON_FUNC  Table_front ( ::Falcon::VMachine *vm )
 
    if( table->empty() ) // empty() is virtual
    {
-      vm->raiseModError( new AccessError( ErrorParam( e_arracc, __LINE__ ).
-         origin( e_orig_runtime ) ) );
-      return;
+      throw new AccessError( ErrorParam( e_arracc, __LINE__ ).
+         origin( e_orig_runtime ) );
    }
 
    vm->retval( table->front() );
@@ -278,8 +268,7 @@ FALCON_FUNC  Table_front ( ::Falcon::VMachine *vm )
    @raise AccessError if the table is empty.
    @return The last item in the table.
 
-   This method overloads the BOM method @a BOM.back. If the table
-   is not empty, it returns the last element.
+   If the table is not empty, it returns the last element (row) in the table.
 */
 FALCON_FUNC  Table_back ( ::Falcon::VMachine *vm )
 {
@@ -287,24 +276,21 @@ FALCON_FUNC  Table_back ( ::Falcon::VMachine *vm )
 
    if( table->empty() )  // empty() is virtual
    {
-      vm->raiseModError( new AccessError( ErrorParam( e_arracc, __LINE__ ).
-         origin( e_orig_runtime ) ) );
-      return;
+      throw new AccessError( ErrorParam( e_arracc, __LINE__ ).
+         origin( e_orig_runtime ) );
    }
 
    vm->retval( table->back() );
 }
 
-extern "C" {
 static void internal_first_last( VMachine *vm, bool mode )
 {
    CoreTable *table = static_cast<CoreTable *>( vm->self().asObject()->getUserData() );
 
    if( table->empty() )  // empty() is virtual
    {
-      vm->raiseModError( new AccessError( ErrorParam( e_arracc, __LINE__ ).
-         origin( e_orig_runtime ) ) );
-      return;
+      throw new AccessError( ErrorParam( e_arracc, __LINE__ ).
+         origin( e_orig_runtime ) );
    }
 
 
@@ -312,10 +298,9 @@ static void internal_first_last( VMachine *vm, bool mode )
    fassert( i_iclass != 0 );
 
    CoreObject *iobj = i_iclass->asClass()->createInstance();
-   iobj->setUserData( table->getIterator(mode) );
+   iobj->setUserData( new Iterator( table, mode) );
    vm->retval( iobj );
 }
-}
 
 /*#
    @method first Table
@@ -354,10 +339,9 @@ static uint32 internal_col_pos( CoreTable *table, VMachine *vm, Item *i_column )
       if ( colPos == CoreTable::noitem )
       {
          // there isn't such field
-         vm->raiseModError( new AccessError( ErrorParam( e_prop_acc, __LINE__ )
+         throw new AccessError( ErrorParam( e_prop_acc, __LINE__ )
             .origin( e_orig_runtime )
-            .extra( *i_column->asString() ) ) );
-         return CoreTable::noitem;
+            .extra( *i_column->asString() ) );
       }
    }
    else {
@@ -367,10 +351,9 @@ static uint32 internal_col_pos( CoreTable *table, VMachine *vm, Item *i_column )
          String temp;
          temp = "col ";
          temp.writeNumber( (int64) colPos );
-         vm->raiseModError( new AccessError( ErrorParam( e_prop_acc, __LINE__ )
+         throw new AccessError( ErrorParam( e_prop_acc, __LINE__ )
             .origin( e_orig_runtime )
-            .extra( temp ) ) );
-         return CoreTable::noitem;
+            .extra( temp ) );
       }
    }
 
@@ -397,7 +380,7 @@ static void internal_get_item( CoreTable *table, CoreArray *row, VMachine *vm, I
 
       // eventually methodize.
       if ( ret.isFunction() )
-         ret.setTabMethod( row, ret.asFunction(), ret.asModule() );
+         ret.setMethod( row, ret.asFunction() );
 
       vm->retval( ret );
    }
@@ -424,10 +407,9 @@ FALCON_FUNC  Table_get ( ::Falcon::VMachine *vm )
    if ( i_pos == 0 || ! i_pos->isOrdinal()
       || ( i_column != 0 && ! (i_column->isString() || i_column->isOrdinal()) ) )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "N, [S|N]" ) ) );
-      return;
+         .extra( "N, [S|N]" ) );
    }
 
    CoreArray* page = table->currentPage();
@@ -436,9 +418,8 @@ FALCON_FUNC  Table_get ( ::Falcon::VMachine *vm )
    uint32 pos = (uint32) i_pos->forceInteger();
    if ( pos >= page->length() )
    {
-      vm->raiseModError( new AccessError( ErrorParam( e_prop_acc, __LINE__ )
-         .origin( e_orig_runtime ) ) );
-      return;
+      throw new AccessError( ErrorParam( e_prop_acc, __LINE__ )
+         .origin( e_orig_runtime ) );
    }
 
    // Should we also get a single item?
@@ -467,10 +448,9 @@ FALCON_FUNC  Table_columnPos ( ::Falcon::VMachine *vm )
 
    if ( i_column != 0 && ! i_column->isString() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "S" ) ) );
-      return;
+         .extra( "S" ) );
    }
 
    uint32 colpos = table->getHeaderPos( *i_column->asString() );
@@ -491,8 +471,7 @@ FALCON_FUNC  Table_columnPos ( ::Falcon::VMachine *vm )
    column data is changed. Anyhow, the previous value is returned.
 
    Notice that the column data of an existing column may be nil; to know
-   if a column with a given name exists, use the @a Table.column method.
-
+   if a column with a given name exists, use the @a Table.columnPos method.
 */
 
 FALCON_FUNC  Table_columnData ( ::Falcon::VMachine *vm )
@@ -503,10 +482,9 @@ FALCON_FUNC  Table_columnData ( ::Falcon::VMachine *vm )
 
    if ( i_column != 0 && ! i_column->isString() && ! i_column->isOrdinal() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "S" ) ) );
-      return;
+         .extra( "S" ) );
    }
 
    uint32 colpos = internal_col_pos( table, vm, i_column );
@@ -533,7 +511,7 @@ FALCON_FUNC  Table_columnData ( ::Falcon::VMachine *vm )
    also, it inherits all the table clumns, that can be accessed as bindings with the
    dot accessor and will resolve in one of the element in the array.
 
-   In case of success, through the BOM method @a BOM.tabRow it is possible to retreive
+   In case of success, through the BOM method @a Array.tabRow it is possible to retreive
    the table row position of the returned array.
 */
 FALCON_FUNC  Table_find ( ::Falcon::VMachine *vm )
@@ -547,10 +525,9 @@ FALCON_FUNC  Table_find ( ::Falcon::VMachine *vm )
         i_value == 0 ||
         ( i_tcol != 0 && ! (i_tcol->isString()|| i_tcol->isOrdinal()) ) )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "S|N,X,[S|N]" ) ) );
-      return;
+         .extra( "S|N,X,[S|N]" ) );
    }
 
    CoreArray* page = table->currentPage();
@@ -567,22 +544,18 @@ FALCON_FUNC  Table_find ( ::Falcon::VMachine *vm )
 
    for ( uint32 i = 0; i < page->length(); i++ )
    {
-      if( vm->compareItems( page->at(i).asArray()->at(col), *i_value ) == 0 )
+      if( page->at(i).asArray()->at(col) == *i_value )
       {
          pos = i;
          break;
       }
-
-      if ( vm->hadError() )
-         return;
    }
 
    if ( pos == CoreTable::noitem )
    {
       // there isn't such field
-      vm->raiseModError( new AccessError( ErrorParam( e_prop_acc, __LINE__ )
-         .origin( e_orig_runtime )));
-      return;
+      throw new AccessError( ErrorParam( e_prop_acc, __LINE__ )
+         .origin( e_orig_runtime ));
    }
 
    // we know we have a valid pos here.
@@ -623,20 +596,18 @@ FALCON_FUNC  Table_insert ( ::Falcon::VMachine *vm )
         || i_element == 0 || ! i_element->isArray()
         )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "N,A" ) ) );
-      return;
+         .extra( "N,A" ) );
    }
 
    CoreArray* element = i_element->asArray();
    uint32 pos = (uint32)( i_pos->isNil() ? table->order() : i_pos->forceInteger());
    if ( element->length() != table->order() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_param_type, __LINE__ )
+      throw new ParamError( ErrorParam( e_param_type, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR( rtl_invalid_tabrow ) ) ) );
-      return;
+         .extra( Engine::getMessage( rtl_invalid_tabrow ) ) );
    }
 
    CoreArray* page = table->currentPage();
@@ -668,10 +639,9 @@ FALCON_FUNC  Table_remove ( ::Falcon::VMachine *vm )
 
    if (i_row == 0 || ! i_row->isOrdinal() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "N" ) ) );
-      return;
+         .extra( "N" ) );
    }
 
    uint32 pos = (uint32) i_row->forceInteger();
@@ -681,9 +651,8 @@ FALCON_FUNC  Table_remove ( ::Falcon::VMachine *vm )
       pos = page->length() - pos;
 
    if ( pos >= page->length() ) {
-      vm->raiseModError( new AccessError( ErrorParam( e_param_range, __LINE__ )
-         .origin( e_orig_runtime ) ) );
-      return;
+      throw new AccessError( ErrorParam( e_param_range, __LINE__ )
+         .origin( e_orig_runtime ) );
    }
 
    CoreArray *rem = (*page)[pos].asArray();
@@ -713,10 +682,9 @@ FALCON_FUNC  Table_setColumn ( ::Falcon::VMachine *vm )
    if (i_column == 0 || ! ( i_column->isOrdinal()|| i_column->isString())
       || i_name == 0 || ! ( i_name->isNil() || i_name->isString()) )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "N|S, Nil|S, [X]" ) ) );
-      return;
+         .extra( "N|S, Nil|S, [X]" ) );
    }
 
    uint32 colpos = internal_col_pos( table, vm, i_column );
@@ -763,10 +731,9 @@ FALCON_FUNC  Table_insertColumn ( ::Falcon::VMachine *vm )
    if ( i_column == 0 || ! ( i_column->isOrdinal()|| i_column->isString())
       || i_name == 0 || ! i_name->isString() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "N|S, S, [X], [X]" ) ) );
-      return;
+         .extra( "N|S, S, [X], [X]" ) );
    }
 
    uint32 colpos;
@@ -818,10 +785,9 @@ FALCON_FUNC  Table_removeColumn ( ::Falcon::VMachine *vm )
 
    if ( i_column == 0 || ! ( i_column->isOrdinal() || i_column->isString()) )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "N|S" ) ) );
-      return;
+         .extra( "N|S" ) );
    }
 
    if ( i_column->isOrdinal() && i_column->forceInteger() < 0 )
@@ -840,8 +806,6 @@ FALCON_FUNC  Table_removeColumn ( ::Falcon::VMachine *vm )
    table->removeColumn( colpos );
 }
 
-extern "C"{
-
 static bool table_choice_next( Falcon::VMachine *vm )
 {
    CoreTable *table = static_cast<CoreTable *>( vm->self().asObject()->getUserData() );
@@ -874,10 +838,9 @@ static bool table_choice_next( Falcon::VMachine *vm )
 
       // a bit paranoid, but users may really screw up the table.
       if ( pos > table->biddingsSize() ) {
-         vm->raiseModError( new AccessError( ErrorParam( e_continue_out, __LINE__ )
+         throw new AccessError( ErrorParam( e_continue_out, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR( rtl_broken_table ) ) ) );
-         return false;
+         .extra( Engine::getMessage( rtl_broken_table ) ) );
       }
 
       numeric *biddings = table->biddings();
@@ -936,7 +899,7 @@ static bool table_choice_next( Falcon::VMachine *vm )
       // eventually methodize.
       if ( ret.isFunction() )
       {
-         ret.setTabMethod( page[row].asArray(), ret.asFunction(), ret.asModule() );
+         ret.setMethod( page[row].asArray(), ret.asFunction() );
          vm->callFrame( ret, 0 );
          return true;
       }
@@ -950,12 +913,9 @@ static bool table_choice_next( Falcon::VMachine *vm )
 
       // else, the item is not callable! Raise an error.
       // (it's ok also if we pushed the parameter; stack is unwinded).
-      vm->raiseModError( new AccessError( ErrorParam( e_non_callable, __LINE__ )
+      throw new AccessError( ErrorParam( e_non_callable, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR( rtl_uncallable_col ) ) ) );
-
-      // pitifully, we're done.
-      return false;
+         .extra( Engine::getMessage( rtl_uncallable_col ) ) );
    }
    else {
       // function provided externally
@@ -966,7 +926,6 @@ static bool table_choice_next( Falcon::VMachine *vm )
    // call us again when the frame is done.
    return true;
 }
-}
 
 static void internal_bind_or_choice( VMachine *vm )
 {
@@ -1080,10 +1039,9 @@ FALCON_FUNC  Table_choice ( ::Falcon::VMachine *vm )
          || (i_rows != 0 && ! i_rows->isRange() )
        )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "C,[N|S],[R]" ) ) );
-      return;
+         .extra( "C,[N|S],[R]" ) );
    }
 
    // prepare local stack and function pointer
@@ -1100,7 +1058,7 @@ FALCON_FUNC  Table_choice ( ::Falcon::VMachine *vm )
    @optparam offer Offer column (number or name).
    @optparam rows Range of rows in which to perform the bidding.
    @return The winning row, or the coresponding value in the offer column.
-   @return AccessError if the table or ranges are empty.
+   @raise AccessError if the table or ranges are empty.
 
    This method calls iteratively all the items in a determined column of
    the table, recording their return value, which must be numeric. It is
@@ -1131,10 +1089,9 @@ FALCON_FUNC  Table_bidding ( ::Falcon::VMachine *vm )
          || (i_rows != 0 && ! i_rows->isRange() )
        )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "[N|S],[N|S],[R]" ) ) );
-      return;
+         .extra( "[N|S],[N|S],[R]" ) );
    }
 
    CoreTable *table = static_cast<CoreTable *>( vm->self().asObject()->getUserData() );
@@ -1174,10 +1131,9 @@ FALCON_FUNC  Table_setPage ( ::Falcon::VMachine *vm )
 
    if ( i_page == 0 || ! i_page->isOrdinal() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "N" ) ) );
-      return;
+         .extra( "N" ) );
    }
 
    CoreTable *table = static_cast<CoreTable *>( vm->self().asObject()->getUserData() );
@@ -1187,10 +1143,9 @@ FALCON_FUNC  Table_setPage ( ::Falcon::VMachine *vm )
 
    if ( ! table->setCurrentPage( pid ) )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_param_range, __LINE__ )
+      throw new ParamError( ErrorParam( e_param_range, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR( rtl_no_page ) ) ) );
-      return;
+         .extra( Engine::getMessage( rtl_no_page ) ) );
    }
 }
 
@@ -1224,25 +1179,27 @@ FALCON_FUNC  Table_insertPage ( ::Falcon::VMachine *vm )
    if ( (i_pos != 0 && ! ( i_pos->isOrdinal() || i_pos->isNil() ))
       || ( i_data != 0 && ! i_data->isArray() ) )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "[N],[A]" ) ) );
-      return;
+         .extra( "[N],[A]" ) );
    }
 
    uint32 pos = i_pos == 0 || i_pos->isNil() ? CoreTable::noitem : (uint32) i_pos->forceInteger();
    CoreTable *table = static_cast<CoreTable *>( vm->self().asObject()->getUserData() );
    if ( i_data == 0 )
    {
-      table->insertPage( vm->self().asObject(), new CoreArray(vm), pos );
+      CoreArray* page = new CoreArray;
+      //page->mark( vm->generation() );
+      table->insertPage( vm->self().asObject(), page, pos );
    }
    else {
-      if ( ! table->insertPage( vm->self().asObject(), i_data->asArray()->clone(), pos ) )
+      CoreArray* page = i_data->asArray()->clone();
+      //page->mark( vm->generation() );
+      if ( ! table->insertPage( vm->self().asObject(), page, pos ) )
       {
-         vm->raiseModError( new ParamError( ErrorParam( e_param_type, __LINE__ )
+         throw new ParamError( ErrorParam( e_param_type, __LINE__ )
             .origin( e_orig_runtime )
-            .extra( FAL_STR( rtl_invalid_tabrow ) ) ));
-         return;
+            .extra( Engine::getMessage( rtl_invalid_tabrow ) ) );
       }
    }
 }
@@ -1261,18 +1218,17 @@ FALCON_FUNC  Table_removePage ( ::Falcon::VMachine *vm )
 
    if ( i_pos == 0 || ! i_pos->isOrdinal() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "N" ) ) );
-      return;
+         .extra( "N" ) );
    }
 
    CoreTable *table = static_cast<CoreTable *>( vm->self().asObject()->getUserData() );
    if ( ! table->removePage( (uint32) i_pos->forceInteger() ) )
    {
-      vm->raiseModError( new AccessError( ErrorParam( e_arracc, __LINE__ )
+      throw new AccessError( ErrorParam( e_arracc, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR( rtl_no_page ) ) ) );
+         .extra( Engine::getMessage( rtl_no_page ) ) );
    }
 }
 
@@ -1296,10 +1252,9 @@ FALCON_FUNC  Table_getPage ( ::Falcon::VMachine *vm )
 
    if ( i_pos != 0 && ! i_pos->isOrdinal() )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "[N]" ) ) );
-      return;
+         .extra( "[N]" ) );
    }
 
    CoreTable *table = static_cast<CoreTable *>( vm->self().asObject()->getUserData() );
@@ -1308,10 +1263,9 @@ FALCON_FUNC  Table_getPage ( ::Falcon::VMachine *vm )
 
    if ( page == 0 )
    {
-      vm->raiseModError( new AccessError( ErrorParam( e_arracc, __LINE__ )
+      throw new AccessError( ErrorParam( e_arracc, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( FAL_STR( rtl_no_page ) ) ) );
-      return;
+         .extra( Engine::getMessage( rtl_no_page ) ) );
    }
 
    vm->retval( page->clone() );
@@ -1359,10 +1313,9 @@ FALCON_FUNC  Table_resetColumn ( ::Falcon::VMachine *vm )
         (i_row != 0 && !(i_row->isOrdinal() || i_row->isRange() ))
    )
    {
-      vm->raiseModError( new ParamError( ErrorParam( e_inv_params, __LINE__ )
+      throw new ParamError( ErrorParam( e_inv_params, __LINE__ )
          .origin( e_orig_runtime )
-         .extra( "N|S,[X],[N|R],[X]" ) ) );
-      return;
+         .extra( "N|S,[X],[N|R],[X]" ) );
    }
 
    CoreTable *table = static_cast<CoreTable *>( vm->self().asObject()->getUserData() );
@@ -1390,11 +1343,11 @@ FALCON_FUNC  Table_resetColumn ( ::Falcon::VMachine *vm )
    int32 start, end, step;
    if ( i_row->isRange() )
    {
-      start = i_row->asRangeStart();
+      start = (int32) i_row->asRangeStart();
       if ( start < 0 )
          start = page.length() + start;
 
-      end = i_row->asRangeIsOpen() ? page.length() : i_row->asRangeEnd();
+      end = (int32)( i_row->asRangeIsOpen() ? page.length() : i_row->asRangeEnd());
       if ( end < 0 )
          end = page.length() + end;
 
@@ -1405,7 +1358,7 @@ FALCON_FUNC  Table_resetColumn ( ::Falcon::VMachine *vm )
          // to compensate different closure semantics
          end = temp + 1;
       }
-      step = i_row->asRangeStep();
+      step = (int32) i_row->asRangeStep();
       if ( step == 0 )
          step = 1;
    }
@@ -1418,9 +1371,8 @@ FALCON_FUNC  Table_resetColumn ( ::Falcon::VMachine *vm )
    }
 
    if ( ((uint32)start) >= page.length() || ((uint32)end) > page.length() ) {
-      vm->raiseModError( new ParamError( ErrorParam( e_param_range, __LINE__ )
-         .origin( e_orig_runtime ) ) );
-      return;
+      throw new ParamError( ErrorParam( e_param_range, __LINE__ )
+         .origin( e_orig_runtime ) );
    }
 
    Item dummyTrue;
@@ -1435,6 +1387,7 @@ FALCON_FUNC  Table_resetColumn ( ::Falcon::VMachine *vm )
    }
 }
 
+}
 }
 
 /* end of table.cpp */
