@@ -39,6 +39,7 @@
 #define FALCON_REGEX_ERROR_BASE           1160
 #define FALCON_SOCKET_ERROR_BASE          1170
 #define FALCON_ZLIB_ERROR_BASE            1190
+#define FALCON_LOGGING_ERROR_BASE         1200
 
 #define FALCON_DBI_ERROR_BASE             2000
 #define FALCON_THREADING_ERROR_BASE       2050
@@ -46,7 +47,7 @@
 #define FALCON_PDF_ERROR_BASE             2200
 #define FALCON_ERROR_DYNLIB_BASE          2250
 #define FALCON_ERROR_DBUS_BASE            2300
-
+#define FALCON_ERROR_GD_BASE              2330
 
 #define FALCON_USER_ERROR_BASE   10000
 
