@@ -37,7 +37,7 @@ class AttribMap;
 
 /** Module class abstraction.
 
-   A module is uniquely individuated by its name; loading a module which has the same name of a
+   A module is uniquely indicated by its name; loading a module which has the same name of a
    previous one will make the other existing module to be discarded.
 
    When a module is added to the VM, it requests the module symbol table. The exported symbols
@@ -89,14 +89,14 @@ protected:
 
       The loader provides internally a system to provide resource reference
       counting, so that if it insists on the same handler as other loaders
-      (contained by other module instances), the corrct library handler count
+      (contained by other module instances), the correct library handler count
       is kept (Actually, this service is usually available at kernel level on
       many OSs).
 
       Also, DllLoader instance contains usually a minimal representation for
       the DLL handler and points to a minimal set of non-virtual methods to
       manage it, so it has the same weight as a reference count or even a
-      poiter to the an handler. This justifies the presence of this field
+      pointer to the an handler. This justifies the presence of this field
       also in modules that are not generated by DLLs, but are loaded from
       binary Falcon objects.
    */
@@ -662,6 +662,7 @@ public:
     *     module->rollBackSymbols( modSize );
     *     throw;
     *  }
+    *  @endcode
     */
    void rollBackSymbols( uint32 size );
 };
