@@ -1,6 +1,6 @@
 /*
    FALCON - The Falcon Programming Language.
-   FILE: socket.cpp
+   FILE: confparser.cpp
 
    The configuration parser module.
    -------------------------------------------------------------------
@@ -8,7 +8,7 @@
    Begin: 2006-05-09 15:50
 
    -------------------------------------------------------------------
-   (C) Copyright 2004: the FALCON developers (see list in AUTHORS file)
+   (C) Copyright 2006: the FALCON developers (see list in AUTHORS file)
 
    See LICENSE file for licensing details.
 */
@@ -177,5 +177,5 @@ FALCON_MODULE_DECL
    return self;
 }
 
-/* end of socket.cpp */
+/* end of confparser.cpp */
 
